@@ -20,7 +20,7 @@
 import logging
 import os
 import re
-from typing import Optional, Tuple
+from typing import Optional, Tuple, Type, List
 import warnings
 
 from . import shebang_binary, UnidentifiedError
@@ -1733,7 +1733,7 @@ class PerlBuildTiny(BuildSystem):
             return cls(path)
 
 
-BUILDSYSTEM_CLSES = [
+BUILDSYSTEM_CLSES: List[Type[BuildSystem]] = [
     Pear,
     SetupPy,
     Npm,
@@ -1758,6 +1758,13 @@ BUILDSYSTEM_CLSES = [
 ]
 
 
+def lookup_buildsystem_cls(name: str) -> Type[BuildSystem]:
+    for bs in BUILDSYSTEM_CLSES:
+        if bs.name == name:
+            return bs
+    raise KeyError(name)
+
+
 def scan_buildsystems(path):
     """Detect build systems."""
     ret = []
