@@ -51,10 +51,9 @@ def run_apt(
     retcode, lines = run_with_tee(session, args, cwd="/", user="root")
     if retcode == 0:
         return
-    for line in reversed(lines):
-        match, error = find_apt_get_failure(line.rstrip('\n'))
-        if error is not None:
-            raise DetailedFailure(retcode, args, error)
+    match, error = find_apt_get_failure(lines)
+    if error is not None:
+        raise DetailedFailure(retcode, args, error)
     while lines and lines[-1].rstrip('\n') == "":
         lines.pop(-1)
     raise UnidentifiedError(retcode, args, lines, secondary=match)
